summaryrefslogtreecommitdiffstats
path: root/cpu/blackfin/start.S
diff options
context:
space:
mode:
authorMike Frysinger <vapier@gentoo.org>2008-06-01 01:21:34 -0400
committerMike Frysinger <vapier@gentoo.org>2009-01-28 13:26:14 -0500
commitdc2bfb0b58d7462b9eba68f3ae38e38cada0ad33 (patch)
treef3c526025260131bd4332d5bb90bb0ef69ca26f7 /cpu/blackfin/start.S
parent362c943347364e9373af4c5530778491ab56ec2e (diff)
downloadblackbird-obmc-uboot-dc2bfb0b58d7462b9eba68f3ae38e38cada0ad33.tar.gz
blackbird-obmc-uboot-dc2bfb0b58d7462b9eba68f3ae38e38cada0ad33.zip
Blackfin: use common memcpy routine during init
Rather than using a local custom memcpy function, just call the existing optimized Blackfin version. Signed-off-by: Mike Frysinger <vapier@gentoo.org>
Diffstat (limited to 'cpu/blackfin/start.S')
-rw-r--r--cpu/blackfin/start.S32
1 files changed, 11 insertions, 21 deletions
diff --git a/cpu/blackfin/start.S b/cpu/blackfin/start.S
index 9975a0c62f..6c5fef7a52 100644
--- a/cpu/blackfin/start.S
+++ b/cpu/blackfin/start.S
@@ -125,8 +125,9 @@ ENTRY(_start)
*/
r6 = 1 (x);
/* Relocate from wherever are (FLASH/RAM/etc...) to the
* hardcoded monitor location in the end of RAM.
*/
serial_early_puts("Relocate");
call _get_pc;
@@ -135,27 +136,16 @@ ENTRY(_start)
r2.h = .Loffset;
r3.l = _start;
r3.h = _start;
- r1 = r2 - r3;
-
- r0 = r0 - r1;
-
- cc = r0 == r3;
+ r2 = r2 - r3;
+ r1 = r0 - r2;
+ cc = r1 == r3;
if cc jump .Lnorelocate;
-
r6 = 0 (x);
- p1 = r0;
-
- p2.l = LO(CONFIG_SYS_MONITOR_BASE);
- p2.h = HI(CONFIG_SYS_MONITOR_BASE);
-
- p3 = 0x04;
- p4.l = LO(CONFIG_SYS_MONITOR_BASE + CONFIG_SYS_MONITOR_LEN);
- p4.h = HI(CONFIG_SYS_MONITOR_BASE + CONFIG_SYS_MONITOR_LEN);
-.Lloop1:
- r1 = [p1 ++ p3];
- [p2 ++ p3] = r1;
- cc=p2==p4;
- if !cc jump .Lloop1;
+
+ r0 = r3;
+ r2.l = LO(CONFIG_SYS_MONITOR_LEN);
+ r2.h = HI(CONFIG_SYS_MONITOR_LEN);
+ call _memcpy_ASM;
/* Initialize BSS section ... we know that memset() does not
* use the BSS, so it is safe to call here. The bootrom LDR
OpenPOWER on IntegriCloud
@@ -125,8 +125,9 @@ ENTRY(_start)
*/
r6 = 1 (x);
- /* Relocate from wherever are (FLASH/RAM/etc...) to the
- * hardcoded monitor location in the end of RAM.
+ /* Relocate from wherever are (FLASH/RAM/etc...) to the hardcoded
+ * monitor location in the end of RAM. We know that memcpy() only
+ * uses registers, so it is safe to call here.
*/
serial_early_puts("Relocate");